@@ -1,25 +1,25 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh ;
-$Config::Model::Backend::OpenSsh::VERSION = '1.237';
+$Config::Model::Backend::OpenSsh::VERSION = '1.239';
 use 5.10.1;
 
-use Config::Model 2.050;
+use Config::Model 2.123;
 
 use Mouse ;
 extends "Config::Model::Backend::Any" ;
 
-has 'current_node'  => ( 
-    is => 'rw', 
+has 'current_node'  => (
+    is => 'rw',
     isa => 'Config::Model::Node',
-    weak_ref => 1 
+    weak_ref => 1
 ) ;
 
 
@@ -39,23 +39,15 @@ my @dispatch = (
     qr/\w/                     => 'assign',
 );
 
-sub suffix {return '';}
-
 sub read {
     my $self = shift ;
     my %args = @_ ;
     my $config_root = $args{object}
-      || croak __PACKAGE__," read_ssh_file: undefined config root object";
+        || croak __PACKAGE__," read_ssh_file: undefined config root object";
 
     $logger->info("loading config file ".$args{file_path});
 
-    my $fh = $args{io_handle} ;
-    if (not defined $fh) {
-        $logger->warn("cannot read $args{file_path}");
-        return 0;
-    }
-
-    my @lines = $fh->getlines ;
+    my @lines = $args{file_path}->lines_utf8 ;
     # try to get global comments (comments before a blank line)
     $self->read_global_comments(\@lines,'#') ;
 
@@ -80,7 +72,6 @@ sub read {
             warn __PACKAGE__, " unknown keyword: $k" if $i >= @dispatch;
         }
     }
-    $fh->close;
     return 1;
 }
 
@@ -89,16 +80,15 @@ sub ssh_write {
     my %args = @_ ;
 
     my $config_root = $args{object}
-      || croak __PACKAGE__," ssh_write: undefined config root object";
+        || croak __PACKAGE__," ssh_write: undefined config root object";
 
     $logger->info("writing config file $args{file_path}");
 
-    my $ioh = $args{io_handle} || croak __PACKAGE__," ssh_write: undefined io_handle";;
-    $self->write_global_comment($ioh,'#') ;
+    my $result = $self->write_global_comment('#') ;
 
-    my $result = $self->write_node_content($config_root,$args{ssh_mode});
+    $result .= $self->write_node_content($config_root,$args{ssh_mode});
 
-    $ioh->print ($result);
+    $args{file_path}->spew_utf8($result);
 
     return 1;
 }
@@ -127,12 +117,12 @@ sub assign {
     #print "got $key type $type and ",join('+',@$arg),"\n";
 
     $elt->annotation($comment) if $comment and $type ne 'hash';
-    
-    if    ($type eq 'leaf') { 
-	$elt->store( join(' ',@$arg) ) ;
+
+    if ($type eq 'leaf') {
+        $elt->store( join(' ',@$arg) ) ;
     }
-    elsif ($type eq 'list') { 
-	$elt->push ( @$arg ) ;
+    elsif ($type eq 'list') {
+        $elt->push ( @$arg ) ;
     }
     elsif ($type eq 'hash') {
         my $hv = $elt->fetch_with_id($arg->[0]);
@@ -140,19 +130,19 @@ sub assign {
         $hv->annotation($comment) if $comment;
     }
     elsif ($type eq 'check_list') {
-	my @check = split /,/,$arg->[0] ;
+        my @check = split /,/,$arg->[0] ;
         $elt->set_checked_list (@check) ;
     }
     else {
-       die "OpenSsh::assign did not expect $type for $key\n";
+        die "OpenSsh::assign did not expect $type for $key\n";
     }
-  }
+}
 
 
 sub write_line {
     my ($self, $k, $v, $note) = @_ ;
     return '' unless length($v) ;
-    return $self->write_data_and_comments( undef, '#',sprintf("%-20s %s",$k,$v),$note) ;
+    return $self->write_data_and_comments('#',sprintf("%-20s %s",$k,$v),$note) ;
 }
 
 sub write_list {
@@ -165,7 +155,7 @@ sub write_list {
 sub write_list_in_one_line {
     my ($self,$name,$mode,$elt) = @_;
     my @v = $elt->fetch_all_values(mode => $mode) ;
-    return $self->write_line($name,join(' ',@v)) ;    
+    return $self->write_line($name,join(' ',@v)) ;
 }
 
 # list there list element that must be written on one line with items
@@ -183,47 +173,47 @@ sub write_node_content {
     my $match  = '' ;
 
     foreach my $name ($node->get_element_name() ) {
-	next unless $node->is_element_defined($name) ;
-	my $elt = $node->fetch_element($name) ;
-	my $type = $elt->get_type;
-	my $note = $elt->annotation ;
+        next unless $node->is_element_defined($name) ;
+        my $elt = $node->fetch_element($name) ;
+        my $type = $elt->get_type;
+        my $note = $elt->annotation ;
 
-	#print "got $key type $type and ",join('+',@arg),"\n";
-	if    ($name eq 'Match') { 
-	    $match .= $self->write_all_match_block($elt,$mode) ;
-	}
-	elsif    ($name eq 'Host') { 
-	    $match .= $self->write_all_host_block($elt,$mode) ;
-	}
-	elsif    ($name =~ /^(Local|Remote)Forward$/) { 
-	    map { $result .= $self->write_forward($_,$mode) ;} $elt->fetch_all() ;
-	}
-	elsif    ($type eq 'leaf') { 
-	    my $v = $elt->fetch($mode) ;
-	    if (defined $v and $elt->value_type eq 'boolean') {
-		$v = $v == 1 ? 'yes':'no' ;
-	    }
-	    $result .= $self->write_line($name,$v,$note);
-	}
-	elsif    ($type eq 'check_list') { 
-	    my $v = $elt->fetch($mode) ;
-	    $result .= $self->write_line($name,$v,$note);
-	}
-	elsif ($type eq 'list') { 
-	    $result .= $self->write_data_and_comments(undef,'#', undef, $note) ; 
-	    $result .= $list_as_one_line{$name} ? $self->write_list_in_one_line($name,$mode,$elt)
-                    :                             $self->write_list($name,$mode,$elt) ;
-	}
-	elsif ($type eq 'hash') {
-	    foreach my $k ( $elt->fetch_all_indexes ) {
-		my $o = $elt->fetch_with_id($k);
-		my $v = $o->fetch($mode) ;
-		$result .=  $self->write_line($name,"$k $v", $o->annotation) ;
-	    }
-	}
-	else {
-	    die "OpenSsh::write did not expect $type for $name\n";
-	}
+        #print "got $key type $type and ",join('+',@arg),"\n";
+        if ($name eq 'Match') {
+            $match .= $self->write_all_match_block($elt,$mode) ;
+        }
+        elsif ($name eq 'Host') {
+            $match .= $self->write_all_host_block($elt,$mode) ;
+        }
+        elsif ($name =~ /^(Local|Remote)Forward$/) {
+            map { $result .= $self->write_forward($_,$mode) ;} $elt->fetch_all() ;
+        }
+        elsif ($type eq 'leaf') {
+            my $v = $elt->fetch($mode) ;
+            if (defined $v and $elt->value_type eq 'boolean') {
+                $v = $v == 1 ? 'yes':'no' ;
+            }
+            $result .= $self->write_line($name,$v,$note);
+        }
+        elsif ($type eq 'check_list') {
+            my $v = $elt->fetch($mode) ;
+            $result .= $self->write_line($name,$v,$note);
+        }
+        elsif ($type eq 'list') {
+            $result .= $self->write_data_and_comments('#', undef, $note) ;
+            $result .= $list_as_one_line{$name} ? $self->write_list_in_one_line($name,$mode,$elt)
+                :                             $self->write_list($name,$mode,$elt) ;
+        }
+        elsif ($type eq 'hash') {
+            foreach my $k ( $elt->fetch_all_indexes ) {
+                my $o = $elt->fetch_with_id($k);
+                my $v = $o->fetch($mode) ;
+                $result .=  $self->write_line($name,"$k $v", $o->annotation) ;
+            }
+        }
+        else {
+            die "OpenSsh::write did not expect $type for $name\n";
+        }
     }
 
     return $result.$match ;
@@ -247,17 +237,17 @@ Config::Model::Backend::OpenSsh - Common backend methods for Ssh and Sshd backen
 
 =head1 VERSION
 
-version 1.237
+version 1.239
 
 =head1 SYNOPSIS
 
 None. Inherited by L<Config::Model::Backend::OpenSsh::Ssh> and
-L<Config::Model::Backend::OpenSsh::Sshd>. 
+L<Config::Model::Backend::OpenSsh::Sshd>.
 
 =head1 DESCRIPTION
 
 Methods used by both L<Config::Model::Backend::OpenSsh::Ssh> and
-L<Config::Model::Backend::OpenSsh::Sshd>. 
+L<Config::Model::Backend::OpenSsh::Sshd>.
 
 =head1 SEE ALSO
 
@@ -269,7 +259,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dominique Dumont.
+This software is Copyright (c) 2008-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
