@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::OpenSsh::Sshd ;
-$Config::Model::Backend::OpenSsh::Sshd::VERSION = '1.236';
+$Config::Model::Backend::OpenSsh::Sshd::VERSION = '1.239';
 use Mouse ;
 extends "Config::Model::Backend::OpenSsh" ;
 
@@ -20,7 +20,6 @@ use File::Path ;
 
 my $logger = Log::Log4perl::get_logger("Backend::OpenSsh");
 
-
 sub _host {
     my ($self,$root,$patterns,$comment)  = @_;
     $logger->debug("host: pattern @$patterns # $comment");
@@ -44,11 +43,13 @@ sub _forward {
     my $v6 = ($args->[1] =~ m![/\[\]]!) ? 1 : 0;
 
     # cleanup possible square brackets used for IPv6
-    foreach (@$args) {s/[\[\]]+//g;}
+    foreach (@$args) {
+        s/[\[\]]+//g;
+    }
 
     # reverse enable to assign string to port even if no bind_adress
     # is specified
-    my $re = $v6 ? qr!/! : qr!:! ; 
+    my $re = $v6 ? qr!/! : qr!:! ;
     my ($port,$bind_adr ) = reverse split $re,$args->[0] ;
     my ($host,$host_port) = split $re,$args->[1] ;
 
@@ -76,9 +77,9 @@ sub match {
     $block_obj->annotation($comment) ;
 
     while (@$pairs) {
-       my $criteria = shift @$pairs;
-       my $pattern  = shift @$pairs;
-       $block_obj->load(qq!Condition $criteria="$pattern"!);
+        my $criteria = shift @$pairs;
+        my $pattern  = shift @$pairs;
+        $block_obj->load(qq!Condition $criteria="$pattern"!);
     }
 
     $self->current_node( $block_obj->fetch_element('Settings') );
@@ -102,7 +103,7 @@ sub write_all_match_block {
 
     my $result = '';
     foreach my $elt ($match_elt->fetch_all($mode) ) {
-	$result .= $self->write_match_block($elt,$mode) ;
+        $result .= $self->write_match_block($elt,$mode) ;
     }
 
     return $result ;
@@ -117,20 +118,20 @@ sub write_match_block {
     my $match_body ;
 
     foreach my $name ($match_elt->get_element_name() ) {
-	my $elt = $match_elt->fetch_element($name) ;
+        my $elt = $match_elt->fetch_element($name) ;
 
-	if ($name eq 'Settings') {
-	    $match_body .= $self->write_node_content($elt,$mode)."\n" ;
-	}
-	elsif ($name eq 'Condition') {
-	    $match_line = $self->write_line( 
+        if ($name eq 'Settings') {
+            $match_body .= $self->write_node_content($elt,$mode)."\n" ;
+        }
+        elsif ($name eq 'Condition') {
+            $match_line = $self->write_line(
                 Match => $self->write_match_condition($elt,$mode) ,
                 $match_elt -> annotation
             ) ;
-	}
-	else {
-	    die "write_match_block: unexpected element: $name";
-	}
+        }
+        else {
+            die "write_match_block: unexpected element: $name";
+        }
     }
 
     return $match_line.$match_body ;
@@ -144,9 +145,9 @@ sub write_match_condition {
     my $result = '' ;
 
     foreach my $name ($cond_elt->get_element_name() ) {
-	my $elt = $cond_elt->fetch_element($name) ;
-	my $v = $elt->fetch($mode) ;
-	$result .= " $name $v" if defined $v;
+        my $elt = $cond_elt->fetch_element($name) ;
+        my $v = $elt->fetch($mode) ;
+        $result .= " $name $v" if defined $v;
     }
 
     return $result ;
@@ -170,7 +171,7 @@ Config::Model::Backend::OpenSsh::Sshd - Backend for sshd configuration files
 
 =head1 VERSION
 
-version 1.236
+version 1.239
 
 =head1 SYNOPSIS
 
@@ -187,19 +188,19 @@ These details are not needed for the basic usages explained in L<Config::Model::
 
 =head1 Methods
 
-These read/write functions are part of C<OpenSsh::Sshd> read/write backend. 
-They are 
-declared in sshd configuration model and are called back when needed to read the 
+These read/write functions are part of C<OpenSsh::Sshd> read/write backend.
+They are
+declared in sshd configuration model and are called back when needed to read the
 configuration file and write it back.
 
 =head2 read (object => <sshd_root>, config_dir => ...)
 
-Read F<sshd_config> in C<config_dir> and load the data in the 
+Read F<sshd_config> in C<config_dir> and load the data in the
 C<sshd_root> configuration tree.
 
 =head2 write (object => <sshd_root>, config_dir => ...)
 
-Write F<sshd_config> in C<config_dir> from the data stored in  
+Write F<sshd_config> in C<config_dir> from the data stored in
 C<sshd_root> configuration tree.
 
 =head1 SEE ALSO
@@ -212,7 +213,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dominique Dumont.
+This software is Copyright (c) 2008-2018 by Dominique Dumont.
 
 This is free software, licensed under:
 
