@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-OpenSsh
 #
-# This software is Copyright (c) 2013 by Dominique Dumont.
+# This software is Copyright (c) 2008-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -23,7 +23,7 @@ parameters to apply to the matched items.',
       'Condition',
       {
         'config_class_name' => 'Sshd::MatchCondition',
-        'description' => 'Specify the condition (User, Group, Host, Adress) necessary for this Match block to be applied',
+        'description' => 'Specify the condition (User, Group, Host, Address) necessary for this Match block to be applied',
         'type' => 'node'
       },
       'Settings',
